@@ -107,6 +107,27 @@ class SingleCoil(object):
         )
         return B
 
+    def hanson_hirshman(self, pos):
+        """Wrapper for the fortran code biotsavart.hanson_hirshman
+
+        Args:
+            pos (ndarray, (n,3)): Evaluation points in space
+
+        Returns:
+            ndarray, (n,3): Magnetic field at the evaluation point
+        """
+        from coilpy_fortran import hanson_hirshman
+
+        xyz = np.transpose([self.x, self.y, self.z])
+        return hanson_hirshman(pos, xyz, self.I)
+
+    def biot_savart(self, pos):
+        from coilpy_fortran import biot_savart
+
+        xyz = np.transpose([self.x, self.y, self.z])
+        dxyz = np.transpose([self.xt * self.dt, self.yt * self.dt, self.zt * self.dt])
+        return biot_savart(pos, xyz[:-1, :], self.I, dxyz[:-1, :])
+
     def fourier_tangent(self):
         """
         Approximate the tangent using Fourier representation.
@@ -600,7 +621,7 @@ class Coil(object):
         return cls(xx=xx, yy=yy, zz=zz, II=II, names=names, groups=groups)
 
     @classmethod
-    def read_gepc_coils(cls, filename, current=1.0):
+    def read_gpec_coils(cls, filename, current=1.0):
         """Read coils from GPEC files.
 
         Args:
@@ -704,6 +725,52 @@ class Coil(object):
             wfile.write("end \n")
         return
 
+    def save_gpec_coils(self, filename, split=True, nw=1, **kwargs):
+        """Write the data in standard ascii format for GPEC
+
+        Args:
+            filename (str): path (if split==True) or file name to be saved.
+            split (bool, optional): write each coil into a separate file. Defaults to True
+            nw (integer, optional): number of windings. Defaults to 1.
+        """
+        if split:
+            # write in independent files
+            for icoil in list(self):
+                with open(filename + icoil.name + ".dat", "w") as f:
+                    # write the defining parameters
+                    ncoil = 1
+                    s = 1  # have to assume this?
+                    nsec = len(icoil.x)
+                    f.write(
+                        "{:>5}{:>5}{:>5}{:8.2f}\n".format(ncoil, s, nsec, nw)
+                    )  # the first line with periods
+                    # write each coil x, y, z
+                    for i in range(len(icoil.x)):
+                        f.write(
+                            "{:13.4e}{:13.4e}{:13.4e}\n".format(
+                                icoil.x[i], icoil.y[i], icoil.z[i]
+                            )
+                        )
+        else:
+            # write into one file
+            with open(filename, "w") as f:
+                # write the defining parameters
+                ncoil = len(self)
+                s = 1  # have to assume this?
+                nsec = len(self.data[0].x)
+                f.write(
+                    "{:>5}{:>5}{:>5}{:8.2f}\n".format(ncoil, s, nsec, nw)
+                )  # the first line with periods
+                # write each coil x, y, z
+                for icoil in list(self):
+                    for i in range(len(icoil.x)):
+                        f.write(
+                            "{:13.4e}{:13.4e}{:13.4e}\n".format(
+                                icoil.x[i], icoil.y[i], icoil.z[i]
+                            )
+                        )
+        return
+
     def toVTK(self, vtkname, line=True, **kwargs):
         """Write entire coil set into a VTK file
 
