@@ -563,7 +563,14 @@ def booz2focus(booz_file, ns=-1, focus_file="plasma.boundary", tol=1e-6, Nfp=1):
             if (abs(rbc[imn]) + abs(zbs[imn] + abs(pmns[imn]))) > tol:
                 fofile.write(
                     "{:4d}  {:4d} \t {:23.15E}  {:12.5E}  {:12.5E}  {:23.15E}  {:12.5E}  {:23.15E} \n".format(
-                        xn[imn], xm[imn], rbc[imn], 0.0, 0.0, zbs[imn], 0.0, pmns[imn]
+                        int(xn[imn]),
+                        xm[imn],
+                        rbc[imn],
+                        0.0,
+                        0.0,
+                        zbs[imn],
+                        0.0,
+                        pmns[imn],
                     )
                 )
         fofile.write("#Bn harmonics \n")
@@ -610,8 +617,8 @@ def read_focus_boundary(filename):
         for i in range(num):
             line = f.readline()
             line_list = line.split()
-            n = int(line_list[0])
-            m = int(line_list[1])
+            n = int(float(line_list[0]))
+            m = int(float(line_list[1]))
             xm.append(m)
             xn.append(n)
             rbc.append(float(line_list[2]))
@@ -636,8 +643,8 @@ def read_focus_boundary(filename):
         for i in range(nbn):
             line = f.readline()
             line_list = line.split()
-            n = int(line_list[0])
-            m = int(line_list[1])
+            n = int(float(line_list[0]))
+            m = int(float(line_list[1]))
             xm.append(m)
             xn.append(n)
             bnc.append(float(line_list[2]))
@@ -652,3 +659,14 @@ def read_focus_boundary(filename):
 
 def div0(a, b):
     return np.divide(a, b, out=np.zeros_like(a), where=b != 0)
+
+
+def biot_savart(pos, xyz, current, dxyz=None):
+    from coilpy_fortran import hanson_hirshman, biot_savart
+
+    if dxyz is None:
+        # no tangent provided
+        return hanson_hirshman(pos, xyz, current)
+    else:
+        # tangent provided
+        return biot_savart(pos, xyz, current, dxyz)
\ No newline at end of file
