@@ -1,4 +1,5 @@
 import numpy as np
+from .misc import read_focus_boundary
 
 
 class FourSurf(object):
@@ -41,33 +42,17 @@ class FourSurf(object):
         Returns:
           fourier_surface class
         """
-        with open(filename, "r") as f:
-            line = f.readline()  # skip one line
-            line = f.readline()
-            num = int(line.split()[0])  # harmonics number
-            nfp = int(line.split()[1])  # number of field periodicity
-            nbn = int(line.split()[2])  # number of Bn harmonics
-            xm = []
-            xn = []
-            rbc = []
-            rbs = []
-            zbc = []
-            zbs = []
-            line = f.readline()  # skip one line
-            line = f.readline()  # skip one line
-            for i in range(num):
-                line = f.readline()
-                line_list = line.split()
-                n = int(line_list[0])
-                m = int(line_list[1])
-                if abs(m) > Mpol or abs(n) > Ntor:
-                    continue
-                xm.append(m)
-                xn.append(n)
-                rbc.append(float(line_list[2]))
-                rbs.append(float(line_list[3]))
-                zbc.append(float(line_list[4]))
-                zbs.append(float(line_list[5]))
+        focus = read_focus_boundary(filename)
+        nfp = focus["nfp"]
+        xm = focus["surface"]["xm"]
+        xn = focus["surface"]["xn"]
+        cond = np.logical_and(np.abs(xm) <= Mpol, np.abs(xn) <= Ntor)
+        xm = xm[cond]
+        xn = xn[cond]
+        rbc = focus["surface"]["rbc"][cond]
+        rbs = focus["surface"]["rbs"][cond]
+        zbc = focus["surface"]["zbc"][cond]
+        zbs = focus["surface"]["zbs"][cond]
         return cls(
             xm=np.array(xm),
             xn=np.array(xn) * nfp,
@@ -483,8 +468,8 @@ class FourSurf(object):
           npol -- integer, number of poloidal discretization points (default: 360)
           ntor -- integer, number of toroidal discretization points (default: 360)
           normal -- bool, if calculating the normal vector (default: False)
-          fig -- , figure to be plotted ion (default: None)
-          ax -- , axis to be plotted ion (default: None)
+          fig -- , figure to be plotted on (default: None)
+          ax -- , axis to be plotted on (default: None)
           show -- bool, if show the plotly figure immediately (default: True)
           kwargs -- optional keyword arguments for plotting
 
@@ -524,6 +509,10 @@ class FourSurf(object):
         elif engine == "plotly":
             import plotly.graph_objects as go
 
+            if "color" in list(kwargs.keys()):
+                color = kwargs["color"]
+                del kwargs["color"]
+                kwargs["colorscale"] = [[0, color], [1, color]]
             if fig is None:
                 fig = go.Figure()
             fig.add_trace(go.Surface(x=xsurf, y=ysurf, z=zsurf, **kwargs))
@@ -574,6 +563,38 @@ class FourSurf(object):
         gridToVTK(vtkname, _xx, _yy, _zz, pointData=kwargs)
         return
 
+    def toSTL(self, stlname, **kwargs):
+        """save surface shape a stl file using meshio
+
+        Parameters:
+          stlname -- string, the filename you want to save, final name is 'stlname.vts'
+          kwargs -- optional keyword arguments used for self.plot3d.
+
+        Returns:
+          mesh: Mesh object in meshio
+
+        """
+        import meshio
+
+        kwargs.setdefault("npol", 120)
+        kwargs.setdefault("ntor", 180)
+        _xx, _yy, _zz, _nn = self.plot3d("noplot", **kwargs)
+        npol = kwargs["npol"]
+        ntor = kwargs["ntor"]
+        points = np.ascontiguousarray(
+            np.transpose([_xx.ravel(), _yy.ravel(), _zz.ravel()])
+        )
+        con = []
+        for i in range(npol - 1):
+            for j in range(ntor - 1):
+                ij = i * ntor + j
+                con.append([ij, ij + 1, ij + ntor + 1])
+                con.append([ij, ij + ntor, ij + ntor + 1])
+        cells = [("triangle", np.array(con))]
+        mesh = meshio.Mesh(points, cells)
+        mesh.write(stlname)
+        return mesh
+
     def write_focus_input(self, filename, Nfp=1, tol=1e-8, **kwargs):
         """write the Fourier harmonics down in FOCUS format
 
